@@ -29,6 +29,8 @@ import mozlog
 import mozversion
 import numpy
 
+from version import __version__
+
 TEST_TYPES = ['startup', 'scrollfps']
 
 
@@ -84,6 +86,8 @@ class DatazillaPerfPoster(object):
 
         self.submit_report = True
         self.ancillary_data = {}
+        self.ancillary_data['generated_by'] = 'b2gperf %s' % __version__
+
         self.device = gaiatest.GaiaDevice(self.marionette)
         dm = mozdevice.DeviceManagerADB()
         self.device.add_device_manager(dm)
@@ -100,6 +104,7 @@ class DatazillaPerfPoster(object):
             'device_firmware_date')
 
         self.required = {
+            'generated by': self.ancillary_data.get('generated_by'),
             'gaia revision': self.ancillary_data.get('gaia_revision'),
             'gecko revision': self.ancillary_data.get('gecko_revision'),
             'build revision': self.ancillary_data.get('build_revision'),
